@@ -8,7 +8,6 @@ import streamlit as st
 from ruamel.yaml import YAML
 import tempfile
 import git
-from classrad.config import config
 
 
 def zip_directory(folder_path, zip_path):
@@ -61,7 +60,6 @@ def load_test_data(out_dir):
     test_out_dir = Path(out_dir) / "test_data"
     test_out_dir.mkdir(exist_ok=True)
     if not dir_nonempty(test_out_dir):
-        st.write("Loading test data to input directory")
         repo_address = "https://github.com/pwoznicki/ClassyRadiomics.git"
         with tempfile.TemporaryDirectory() as tmp_dir:
             git.Git(tmp_dir).clone(repo_address)
